@@ -33,16 +33,16 @@ class NotificationStack(Stack):
         pinpoint_app = pinpoint.CfnApp(self, pinpoint_app_name, name=pinpoint_app_name)  
 
 
-        # cfn_aPNSSandbox_channel = pinpoint.CfnAPNSSandboxChannel(self, "{}-apns-sandbox".format(pinpoint_app_name),
-        #     application_id=pinpoint_app.ref,
+        cfn_aPNSSandbox_channel = pinpoint.CfnAPNSSandboxChannel(self, "{}-apns-sandbox".format(pinpoint_app_name),
+            application_id=pinpoint_app.ref,
 
-        #     # the properties below are optional
-        #     bundle_id=apns_bundle_id,
-        #     certificate=apns_certificate,
-        #     default_authentication_method="certificate", 
-        #     enabled=False,
-        #     # private_key=apns_private_key,
-        #     # team_id="teamId",
-        #     # token_key="tokenKey",
-        #     # token_key_id="tokenKeyId"
-        # )
\ No newline at end of file
+            # the properties below are optional
+            bundle_id=apns_bundle_id,
+            certificate=open(apns_certificate_path).read(),
+            default_authentication_method="certificate", 
+            enabled=False,
+            private_key=open(apns_private_key_path).read(),
+            # team_id="teamId",
+            # token_key="tokenKey",
+            # token_key_id="tokenKeyId"
+        )
\ No newline at end of file
