@@ -1,6 +1,3 @@
-print("AWS CDK TOOLKIT - STORAGE")
-
-
 from constructs import Construct
 from aws_cdk import (
     Aws, 
@@ -8,9 +5,16 @@ from aws_cdk import (
     aws_s3 as s3, 
 )
 
-
-
+##
+## S3 Buckets
 def createS3Bucket(self, bucket_name, versioned=False): 
+    """
+    Creates an S3 Bucket.
+ 
+    :param bucket_name: Name of the S3 Bucket
+    :param versioned: Enable Bucket Versioning (default=False)
+    :return: S3 Bucket Object
+    """ 
     bucket = s3.Bucket(
         self, "DataLakeS3Bucket",
         bucket_name=bucket_name,
@@ -20,4 +24,12 @@ def createS3Bucket(self, bucket_name, versioned=False):
     return bucket
 
 def existingS3Bucket():
-    return 
\ No newline at end of file
+    return 
+
+
+##
+## EFS
+
+
+##
+## EBS
\ No newline at end of file
